@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -33,17 +33,17 @@ public:
     explicit RichTextExternalComposer(RichTextComposer *composer, QObject *parent = nullptr);
     ~RichTextExternalComposer();
 
-    bool useExternalEditor() const;
+    Q_REQUIRED_RESULT bool useExternalEditor() const;
     void setUseExternalEditor(bool value);
 
     void startExternalEditor();
 
     void setExternalEditorPath(const QString &path);
-    QString externalEditorPath() const;
-    bool checkExternalEditorFinished();
+    Q_REQUIRED_RESULT QString externalEditorPath() const;
+    Q_REQUIRED_RESULT bool checkExternalEditorFinished();
     void killExternalEditor();
 
-    bool isInProgress() const;
+    Q_REQUIRED_RESULT bool isInProgress() const;
 
 Q_SIGNALS:
     void externalEditorClosed();
