@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,7 +22,6 @@
 #include "richtexteditfindbar.h"
 
 #include <QVBoxLayout>
-#include <QShortcut>
 #include <QTextCursor>
 #include <texttospeech/texttospeechwidget.h>
 
@@ -34,29 +33,25 @@ class KPIMTextEdit::RichTextEditorWidgetPrivate
 {
 public:
     RichTextEditorWidgetPrivate()
-        : mFindBar(Q_NULLPTR),
-          mEditor(Q_NULLPTR),
-          mTextToSpeechWidget(Q_NULLPTR),
-          mSliderContainer(Q_NULLPTR)
     {
-
     }
-    KPIMTextEdit::RichTextEditFindBar *mFindBar;
-    RichTextEditor *mEditor;
-    KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget;
-    KPIMTextEdit::SlideContainer *mSliderContainer;
+
+    KPIMTextEdit::RichTextEditFindBar *mFindBar = nullptr;
+    RichTextEditor *mEditor = nullptr;
+    KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
+    KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
 };
 
 RichTextEditorWidget::RichTextEditorWidget(RichTextEditor *customEditor, QWidget *parent)
-    : QWidget(parent),
-      d(new KPIMTextEdit::RichTextEditorWidgetPrivate)
+    : QWidget(parent)
+    , d(new KPIMTextEdit::RichTextEditorWidgetPrivate)
 {
     init(customEditor);
 }
 
 RichTextEditorWidget::RichTextEditorWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new KPIMTextEdit::RichTextEditorWidgetPrivate)
+    : QWidget(parent)
+    , d(new KPIMTextEdit::RichTextEditorWidgetPrivate)
 {
     init();
 }
@@ -177,6 +172,8 @@ void RichTextEditorWidget::slotFindNext()
     if (d->mEditor->searchSupport()) {
         if (d->mFindBar->isVisible()) {
             d->mFindBar->findNext();
+        } else {
+            slotFind();
         }
     }
 }
@@ -194,4 +191,3 @@ void RichTextEditorWidget::slotFind()
         d->mFindBar->focusAndSetCursor();
     }
 }
-
