@@ -18,16 +18,12 @@
 */
 
 #include "texttospeechconfiginterface.h"
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
-#include <QtTextToSpeech/QTextToSpeech>
-#endif
+#include <QTextToSpeech>
 using namespace KPIMTextEdit;
 
 TextToSpeechConfigInterface::TextToSpeechConfigInterface(QObject *parent)
     : AbstractTextToSpeechConfigInterface(parent)
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     , mTextToSpeech(new QTextToSpeech(this))
-#endif
 {
 }
 
@@ -38,47 +34,31 @@ TextToSpeechConfigInterface::~TextToSpeechConfigInterface()
 QStringList TextToSpeechConfigInterface::availableVoices() const
 {
     QStringList lst;
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     const QVector<QVoice> voices = mTextToSpeech->availableVoices();
     lst.reserve(voices.count());
     for (const QVoice &voice : voices) {
         lst << voice.name();
     }
-#endif
     return lst;
 }
 
 QStringList TextToSpeechConfigInterface::availableEngines() const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     return mTextToSpeech->availableEngines();
-#else
-    return QStringList();
-#endif
 }
 
 QVector<QLocale> TextToSpeechConfigInterface::availableLocales() const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     return mTextToSpeech->availableLocales();
-#else
-    return QVector<QLocale>();
-#endif
 }
 
 QLocale TextToSpeechConfigInterface::locale() const
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     return mTextToSpeech->locale();
-#else
-    return QLocale();
-#endif
 }
 
 void TextToSpeechConfigInterface::setEngine(const QString &engineName)
 {
-#if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     delete mTextToSpeech;
     mTextToSpeech = new QTextToSpeech(engineName, this);
-#endif
 }
